pub(crate) enum TextRunItem {
LineBreak {
character_index: usize,
},
Tab {
bidi_level: Level,
},
TextSegment(Box<TextRunSegment>),
}Expand description
A single item in a TextRun.
Variants
LineBreak
A hard line break i.e. a “\n” as other types line breaks are normalized to “\n”.
Tab
A preserved tab character that should advance the line to a tab stop.
TextSegment(Box<TextRunSegment>)
Any other text for which a font can be matched. We store a Box here as TextRunSegment
is quite a bit larger than the other enum variants.