character_cannot_change_font

Function character_cannot_change_font 

fn character_cannot_change_font(character: char) -> bool
Whether or not this character should be able to change the font during segmentation. Certain character are not rendered at all, so it doesn’t matter what font we use to render them. They should just be added to the current segment.