pub(crate) struct CaretPlaceholder {
pub run_data: Arc<SharedTextRunData>,
pub base_fragment_info: BaseFragmentInfo,
pub character_index: usize,
}Fields
run_data: Arc<SharedTextRunData>The [TextFragmentRunData] of the TextRun that contains this caret placeholder.
base_fragment_info: BaseFragmentInfoThe BaseFragmentInfo of the originating text node that this caret placeholder is in.
character_index: usizeCharacter index of the preserved newline in the IFC’s transformed text, relative to the start of the DOM node.