pub(crate) struct FontAndScriptInfo {
pub script: Script,
pub font_info: Arc<FontInfo>,
}Expand description
A data structure which contains information used when shaping a TextRunSegment.
Fields
script: ScriptThe script used when shaping a TextRunSegment.
font_info: Arc<FontInfo>The rest of the font information which is never modified.
Implementations
Sourceimpl FontAndScriptInfo
impl FontAndScriptInfo
Sourcepub(crate) fn simple_for_font(font: FontRef) -> Self
pub(crate) fn simple_for_font(font: FontRef) -> Self
Creates a minimal FontAndScriptInfo for a single font, with generic language settings
and the default shaping configuration. This is only used to generate placeholders for
text carets on otherwise empty lines.