pub(crate) struct FontInfo {Show 13 fields
pub font: FontRef,
pub bidi_level: Level,
pub language: Language,
pub letter_spacing: Option<Au>,
pub word_spacing: Option<Au>,
pub text_rendering: T,
pub kerning: T,
pub ligatures: FontVariantLigatures,
pub numeric: FontVariantNumeric,
pub east_asian: FontVariantEastAsian,
pub feature_settings: FontFeatureSettings,
pub position: T,
pub alternates: ResolvedFontVariantAlternates,
}Expand description
A data structure which contains information used when shaping a TextRunSegment.
Fields
font: FontRefThe font used when shaping a TextRunSegment.
bidi_level: LevelThe BiDi Level used when shaping a TextRunSegment.
language: LanguageThe Language used when shaping a TextRunSegment.
letter_spacing: Option<Au>Spacing to add between each letter. Corresponds to the CSS 2.1 letter-spacing property.
Letter spacing is not applied to all characters. Use [Self::letter_spacing_for_character] to determine the amount of spacing to apply.
word_spacing: Option<Au>Spacing to add between each word. Corresponds to the CSS 2.1 word-spacing property.
text_rendering: TThe TextRendering value from the original style.
kerning: TThe value of the font-kerning property from the original style.
ligatures: FontVariantLigaturesThe value of the font-variant-ligatures property from the original style.
numeric: FontVariantNumericThe value of the font-variant-numeric property from the original style.
east_asian: FontVariantEastAsianThe value of the font-variant-east-asian property from the original style.
feature_settings: FontFeatureSettingsThe value of the font-feature-settings property from the original style.
position: TThe value of the font-variant-position property from the original style.
alternates: ResolvedFontVariantAlternatesThe value of the font-variant-alternates property from the original style.
Any alternate names are already resolved at this point.
Implementations