pub(crate) struct TextRun {
pub base_fragment_info: BaseFragmentInfo,
pub run_data: Arc<SharedTextRunData>,
pub parent_box: Option<WeakLayoutBox>,
pub text_range: Range<usize>,
pub items: Vec<TextRunItem>,
}Expand description
A single TextRun for the box tree. These are all descendants of
super::InlineBox or the root of the super::InlineFormattingContext. During
box tree construction, text is split into TextRuns based on their font, script,
etc. When these are created text is already shaped.
Fields
base_fragment_info: BaseFragmentInfoThe BaseFragmentInfo for this TextRun. Usually this comes from the
original text node in the DOM for the text.
run_data: Arc<SharedTextRunData>Data to be used by all [TextFragment]s spawned by this TextRun to avoid
having to clone the data into each fragment.
parent_box: Option<WeakLayoutBox>A weak reference to the parent of this layout box. This becomes valid as soon as the parent of this box is added to the tree.
text_range: Range<usize>The range of text in super::InlineFormattingContext::text_content of the
super::InlineFormattingContext that owns this TextRun. These are UTF-8 offsets.
items: Vec<TextRunItem>The TextRunItems of this text run. This is produced by segmenting the incoming text
by things such as font and script as well as separating out hard line breaks.
segments, and shaped.
Implementations
Sourceimpl TextRun
impl TextRun
pub(crate) fn new( base_fragment_info: BaseFragmentInfo, run_data: Arc<SharedTextRunData>, text_range: Range<usize>, old_text_run: Option<ArcRefCell<TextRun>>, ) -> Self
pub(super) fn inline_styles(&self) -> &SharedInlineStyles
pub(super) fn segment( &mut self, self_arc_ref_cell: ArcRefCell<TextRun>, formatting_context_text: &str, layout_context: &LayoutContext<'_>, bidi_levels: &BidiLevels<'_>, ) -> SmallVec<[ShapingQueueEntry; 1]> ⓘ
Sourcefn segment_text_by_font(
&mut self,
layout_context: &LayoutContext<'_>,
formatting_context_text: &str,
bidi_levels: &BidiLevels<'_>,
parent_style: &ServoArc<ComputedValues>,
) -> Vec<TextRunItem>
fn segment_text_by_font( &mut self, layout_context: &LayoutContext<'_>, formatting_context_text: &str, bidi_levels: &BidiLevels<'_>, parent_style: &ServoArc<ComputedValues>, ) -> Vec<TextRunItem>
Take the TextRun’s text and turn it into TextRunSegments. Each segment has a matched
font and script. Fonts may differ when glyphs are found in fallback fonts.
super::InlineFormattingContext.
pub(super) fn layout_into_line_items( &self, ifc: &mut InlineFormattingContextLayout<'_>, )
fn process_preserved_tab( &self, ifc_layout: &mut InlineFormattingContextLayout<'_>, bidi_level: Level, )