pub(crate) struct TextRunSegment {
pub info: Arc<FontAndScriptInfo>,
pub byte_range: Range<usize>,
pub character_range: Range<usize>,
pub break_at_start: bool,
pub runs: Vec<Arc<ShapedTextSlice>>,
}Fields
info: Arc<FontAndScriptInfo>Information about the font and language used in this text run. This is produced by segmenting the inline formatting context’s text content by font, script, and bidi level.
byte_range: Range<usize>The range of bytes in the parent super::InlineFormattingContext’s text content.
character_range: Range<usize>The range of characters in the parent super::InlineFormattingContext’s text content.
break_at_start: boolWhether or not the linebreaker said that we should allow a line break at the start of this segment.
runs: Vec<Arc<ShapedTextSlice>>The shaped runs within this segment.
Implementations
Sourceimpl TextRunSegment
impl TextRunSegment
fn new( info: Arc<FontAndScriptInfo>, byte_range: Range<usize>, character_range: Range<usize>, ) -> Self
Sourcefn is_compatible(
&self,
new_font: &Option<FontRef>,
new_script: Script,
new_bidi_level: Level,
) -> bool
fn is_compatible( &self, new_font: &Option<FontRef>, new_script: Script, new_bidi_level: Level, ) -> bool
Returns true if the new Font, Script and BiDi Level are compatible with this segment
or false otherwise.
Sourcefn update(
&mut self,
next_byte_index: usize,
next_character_index: usize,
new_script: Script,
)
fn update( &mut self, next_byte_index: usize, next_character_index: usize, new_script: Script, )
Update this segment to end at the given byte and character index. The update will only ever make the Script specific and will not change it otherwise.
fn layout_into_line_items( &self, text_run: &TextRun, soft_wrap_policy: SegmentStartSoftWrapPolicy, ifc: &mut InlineFormattingContextLayout<'_>, )
Sourcefn shape_text(
&mut self,
parent_style: &ComputedValues,
formatting_context_text: &str,
linebreaker: &mut LineBreaker,
old_text_run_item: Option<TextRunItem>,
)
fn shape_text( &mut self, parent_style: &ComputedValues, formatting_context_text: &str, linebreaker: &mut LineBreaker, old_text_run_item: Option<TextRunItem>, )
Shape the text of this TextRunSegment, first finding “words” for the shaper by processing
the linebreaks found in the owning super::InlineFormattingContext. Linebreaks are filtered,
based on the style of the parent inline box.
fn is_compatible_with_old_shaping_result(&self, old_segment: &Self) -> bool