pub(crate) struct FontAndScriptInfo {
pub font: FontRef,
pub script: Script,
pub bidi_level: Level,
pub language: Language,
pub letter_spacing: Option<Au>,
pub word_spacing: Option<Au>,
pub text_rendering: T,
pub kerning: T,
}Expand description
A data structure which contains information used when shaping a TextRunSegment.
Fields
font: FontRefThe font used when shaping a TextRunSegment.
script: ScriptThe script used when shaping a TextRunSegment.
bidi_level: LevelThe BiDi Level used when shaping a TextRunSegment.
language: LanguageThe Language used when shaping a TextRunSegment.
letter_spacing: Option<Au>Spacing to add between each letter. Corresponds to the CSS 2.1 letter-spacing property.
NB: You will probably want to set the IGNORE_LIGATURES_SHAPING_FLAG if this is non-null.
Letter spacing is not applied to all characters. Use [Self::letter_spacing_for_character] to determine the amount of spacing to apply.
word_spacing: Option<Au>Spacing to add between each word. Corresponds to the CSS 2.1 word-spacing property.
text_rendering: TThe TextRendering value from the original style.
kerning: TThe value of the font-kerning property from the original style.
Implementations
Sourceimpl FontAndScriptInfo
impl FontAndScriptInfo
Sourcepub(crate) fn simple_for_font(font: FontRef) -> Self
pub(crate) fn simple_for_font(font: FontRef) -> Self
Creates a minimal FontAndScriptInfo for a single font, with generic language settings
and the default shaping configuration. This is only used to generate placeholders for
text carets on otherwise empty lines.