TextRun

Struct TextRun 

pub(crate) struct TextRun {
    pub base_fragment_info: BaseFragmentInfo,
    pub parent_box: Option<WeakLayoutBox>,
    pub inline_styles: SharedInlineStyles,
    pub text_range: Range<usize>,
    pub character_range: Range<usize>,
    pub items: Vec<TextRunItem>,
}
A single TextRun for the box tree. These are all descendants of super::InlineBox or the root of the super::InlineFormattingContext. During box tree construction, text is split into TextRuns based on their font, script, etc. When these are created text is already shaped.

https://www.w3.org/TR/css-display-3/#css-text-run

Fields

base_fragment_info: BaseFragmentInfo

The BaseFragmentInfo for this TextRun. Usually this comes from the original text node in the DOM for the text.

parent_box: Option<WeakLayoutBox>

A weak reference to the parent of this layout box. This becomes valid as soon as the parent of this box is added to the tree.

inline_styles: SharedInlineStyles

The crate::SharedStyle from this TextRuns parent element. This is shared so that incremental layout can simply update the parent element and this TextRun will be updated automatically.

text_range: Range<usize>

The range of text in super::InlineFormattingContext::text_content of the super::InlineFormattingContext that owns this TextRun. These are UTF-8 offsets.

character_range: Range<usize>

The range of characters in this text in super::InlineFormattingContext::text_content of the super::InlineFormattingContext that owns this TextRun. These are not UTF-8 offsets.

items: Vec<TextRunItem>

The TextRunItems of this text run. This is produced by segmenting the incoming text by things such as font and script as well as separating out hard line breaks. segments, and shaped.

Implementations

Source

impl TextRun

pub(crate) fn new( base_fragment_info: BaseFragmentInfo, inline_styles: SharedInlineStyles, text_range: Range<usize>, character_range: Range<usize>, old_text_run: Option<ArcRefCell<TextRun>>, ) -> Self

pub(super) fn segment_and_shape( &mut self, formatting_context_text: &str, layout_context: &LayoutContext<'_>, linebreaker: &mut LineBreaker, bidi_info: &BidiInfo<'_>, )

fn segment_text_by_font( &mut self, layout_context: &LayoutContext<'_>, formatting_context_text: &str, bidi_info: &BidiInfo<'_>, parent_style: &ServoArc<ComputedValues>, ) -> Vec<TextRunItem>

Take the TextRun’s text and turn it into TextRunSegments. Each segment has a matched font and script. Fonts may differ when glyphs are found in fallback fonts. super::InlineFormattingContext.

pub(super) fn layout_into_line_items( &self, ifc: &mut InlineFormattingContextLayout<'_>, )

fn process_preserved_tab( &self, ifc_layout: &mut InlineFormattingContextLayout<'_>, bidi_level: Level, )